# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/ext_proc/v3alpha/ext_proc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from envoy.extensions.filters.http.ext_proc.v3alpha import processing_mode_pb2 as envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3alpha_dot_processing__mode__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/ext_proc/v3alpha/ext_proc.proto',
  package='envoy.extensions.filters.http.ext_proc.v3alpha',
  syntax='proto3',
  serialized_options=b'\n<io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3alphaB\014ExtProcProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=envoy/extensions/filters/http/ext_proc/v3alpha/ext_proc.proto\x12.envoy.extensions.filters.http.ext_proc.v3alpha\x1a\'envoy/config/core/v3/grpc_service.proto\x1a\x44\x65nvoy/extensions/filters/http/ext_proc/v3alpha/processing_mode.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xd7\x02\n\x11\x45xternalProcessor\x12\x37\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32!.envoy.config.core.v3.GrpcService\x12\x1a\n\x12\x66\x61ilure_mode_allow\x18\x02 \x01(\x08\x12W\n\x0fprocessing_mode\x18\x03 \x01(\x0b\x32>.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode\x12\x12\n\nasync_mode\x18\x04 \x01(\x08\x12\x1a\n\x12request_attributes\x18\x05 \x03(\t\x12\x1b\n\x13response_attributes\x18\x06 \x03(\t\x12\x32\n\x0fmessage_timeout\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x13\n\x0bstat_prefix\x18\x08 \x01(\t\"\x96\x01\n\x0f\x45xtProcPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12U\n\toverrides\x18\x02 \x01(\x0b\x32@.envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcOverridesH\x00\x42\x0f\n\x08override\x12\x03\xf8\x42\x01\"\xb8\x01\n\x10\x45xtProcOverrides\x12W\n\x0fprocessing_mode\x18\x01 \x01(\x0b\x32>.envoy.extensions.filters.http.ext_proc.v3alpha.ProcessingMode\x12\x12\n\nasync_mode\x18\x02 \x01(\x08\x12\x1a\n\x12request_properties\x18\x03 \x03(\t\x12\x1b\n\x13response_properties\x18\x04 \x03(\tB^\n<io.envoyproxy.envoy.extensions.filters.http.ext_proc.v3alphaB\x0c\x45xtProcProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2.DESCRIPTOR,envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3alpha_dot_processing__mode__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_EXTERNALPROCESSOR = _descriptor.Descriptor(
  name='ExternalProcessor',
  full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.grpc_service', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure_mode_allow', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.failure_mode_allow', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.processing_mode', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='async_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.async_mode', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_attributes', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.request_attributes', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_attributes', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.response_attributes', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_timeout', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.message_timeout', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stat_prefix', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor.stat_prefix', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=656,
)


_EXTPROCPERROUTE = _descriptor.Descriptor(
  name='ExtProcPerRoute',
  full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcPerRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disabled', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcPerRoute.disabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004j\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overrides', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcPerRoute.overrides', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='override', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcPerRoute.override',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=659,
  serialized_end=809,
)


_EXTPROCOVERRIDES = _descriptor.Descriptor(
  name='ExtProcOverrides',
  full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcOverrides',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='processing_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcOverrides.processing_mode', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='async_mode', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcOverrides.async_mode', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_properties', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcOverrides.request_properties', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_properties', full_name='envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcOverrides.response_properties', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=812,
  serialized_end=996,
)

_EXTERNALPROCESSOR.fields_by_name['grpc_service'].message_type = envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2._GRPCSERVICE
_EXTERNALPROCESSOR.fields_by_name['processing_mode'].message_type = envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3alpha_dot_processing__mode__pb2._PROCESSINGMODE
_EXTERNALPROCESSOR.fields_by_name['message_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_EXTPROCPERROUTE.fields_by_name['overrides'].message_type = _EXTPROCOVERRIDES
_EXTPROCPERROUTE.oneofs_by_name['override'].fields.append(
  _EXTPROCPERROUTE.fields_by_name['disabled'])
_EXTPROCPERROUTE.fields_by_name['disabled'].containing_oneof = _EXTPROCPERROUTE.oneofs_by_name['override']
_EXTPROCPERROUTE.oneofs_by_name['override'].fields.append(
  _EXTPROCPERROUTE.fields_by_name['overrides'])
_EXTPROCPERROUTE.fields_by_name['overrides'].containing_oneof = _EXTPROCPERROUTE.oneofs_by_name['override']
_EXTPROCOVERRIDES.fields_by_name['processing_mode'].message_type = envoy_dot_extensions_dot_filters_dot_http_dot_ext__proc_dot_v3alpha_dot_processing__mode__pb2._PROCESSINGMODE
DESCRIPTOR.message_types_by_name['ExternalProcessor'] = _EXTERNALPROCESSOR
DESCRIPTOR.message_types_by_name['ExtProcPerRoute'] = _EXTPROCPERROUTE
DESCRIPTOR.message_types_by_name['ExtProcOverrides'] = _EXTPROCOVERRIDES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExternalProcessor = _reflection.GeneratedProtocolMessageType('ExternalProcessor', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALPROCESSOR,
  '__module__' : 'envoy.extensions.filters.http.ext_proc.v3alpha.ext_proc_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_proc.v3alpha.ExternalProcessor)
  })
_sym_db.RegisterMessage(ExternalProcessor)

ExtProcPerRoute = _reflection.GeneratedProtocolMessageType('ExtProcPerRoute', (_message.Message,), {
  'DESCRIPTOR' : _EXTPROCPERROUTE,
  '__module__' : 'envoy.extensions.filters.http.ext_proc.v3alpha.ext_proc_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcPerRoute)
  })
_sym_db.RegisterMessage(ExtProcPerRoute)

ExtProcOverrides = _reflection.GeneratedProtocolMessageType('ExtProcOverrides', (_message.Message,), {
  'DESCRIPTOR' : _EXTPROCOVERRIDES,
  '__module__' : 'envoy.extensions.filters.http.ext_proc.v3alpha.ext_proc_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.ext_proc.v3alpha.ExtProcOverrides)
  })
_sym_db.RegisterMessage(ExtProcOverrides)


DESCRIPTOR._options = None
_EXTPROCPERROUTE.oneofs_by_name['override']._options = None
_EXTPROCPERROUTE.fields_by_name['disabled']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/servicecontrol/v1/log_entry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.logging.type import log_severity_pb2 as google_dot_logging_dot_type_dot_log__severity__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/servicecontrol/v1/log_entry.proto',
  package='google.api.servicecontrol.v1',
  syntax='proto3',
  serialized_options=b'\n com.google.api.servicecontrol.v1B\rLogEntryProtoP\001ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,google/api/servicecontrol/v1/log_entry.proto\x12\x1cgoogle.api.servicecontrol.v1\x1a\x1cgoogle/api/annotations.proto\x1a&google/logging/type/log_severity.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x86\x03\n\x08LogEntry\x12\x0c\n\x04name\x18\n \x01(\t\x12-\n\ttimestamp\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x08severity\x18\x0c \x01(\x0e\x32 .google.logging.type.LogSeverity\x12\x11\n\tinsert_id\x18\x04 \x01(\t\x12\x42\n\x06labels\x18\r \x03(\x0b\x32\x32.google.api.servicecontrol.v1.LogEntry.LabelsEntry\x12-\n\rproto_payload\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x16\n\x0ctext_payload\x18\x03 \x01(\tH\x00\x12\x31\n\x0estruct_payload\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07payloadB\x7f\n com.google.api.servicecontrol.v1B\rLogEntryProtoP\x01ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrolb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_logging_dot_type_dot_log__severity__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_LOGENTRY_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='google.api.servicecontrol.v1.LogEntry.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.api.servicecontrol.v1.LogEntry.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.servicecontrol.v1.LogEntry.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=573,
  serialized_end=618,
)

_LOGENTRY = _descriptor.Descriptor(
  name='LogEntry',
  full_name='google.api.servicecontrol.v1.LogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.api.servicecontrol.v1.LogEntry.name', index=0,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='google.api.servicecontrol.v1.LogEntry.timestamp', index=1,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='severity', full_name='google.api.servicecontrol.v1.LogEntry.severity', index=2,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='insert_id', full_name='google.api.servicecontrol.v1.LogEntry.insert_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='google.api.servicecontrol.v1.LogEntry.labels', index=4,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proto_payload', full_name='google.api.servicecontrol.v1.LogEntry.proto_payload', index=5,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_payload', full_name='google.api.servicecontrol.v1.LogEntry.text_payload', index=6,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='struct_payload', full_name='google.api.servicecontrol.v1.LogEntry.struct_payload', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LOGENTRY_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='google.api.servicecontrol.v1.LogEntry.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=239,
  serialized_end=629,
)

_LOGENTRY_LABELSENTRY.containing_type = _LOGENTRY
_LOGENTRY.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LOGENTRY.fields_by_name['severity'].enum_type = google_dot_logging_dot_type_dot_log__severity__pb2._LOGSEVERITY
_LOGENTRY.fields_by_name['labels'].message_type = _LOGENTRY_LABELSENTRY
_LOGENTRY.fields_by_name['proto_payload'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_LOGENTRY.fields_by_name['struct_payload'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_LOGENTRY.oneofs_by_name['payload'].fields.append(
  _LOGENTRY.fields_by_name['proto_payload'])
_LOGENTRY.fields_by_name['proto_payload'].containing_oneof = _LOGENTRY.oneofs_by_name['payload']
_LOGENTRY.oneofs_by_name['payload'].fields.append(
  _LOGENTRY.fields_by_name['text_payload'])
_LOGENTRY.fields_by_name['text_payload'].containing_oneof = _LOGENTRY.oneofs_by_name['payload']
_LOGENTRY.oneofs_by_name['payload'].fields.append(
  _LOGENTRY.fields_by_name['struct_payload'])
_LOGENTRY.fields_by_name['struct_payload'].containing_oneof = _LOGENTRY.oneofs_by_name['payload']
DESCRIPTOR.message_types_by_name['LogEntry'] = _LOGENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LogEntry = _reflection.GeneratedProtocolMessageType('LogEntry', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LOGENTRY_LABELSENTRY,
    '__module__' : 'google.api.servicecontrol.v1.log_entry_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.LogEntry.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LOGENTRY,
  '__module__' : 'google.api.servicecontrol.v1.log_entry_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.LogEntry)
  })
_sym_db.RegisterMessage(LogEntry)
_sym_db.RegisterMessage(LogEntry.LabelsEntry)


DESCRIPTOR._options = None
_LOGENTRY_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: udpa/annotations/security.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='udpa/annotations/security.proto',
  package='udpa.annotations',
  syntax='proto3',
  serialized_options=b'\272\200\310\321\006\002\010\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fudpa/annotations/security.proto\x12\x10udpa.annotations\x1a\x1dudpa/annotations/status.proto\x1a\x19google/protobuf/any.proto\x1a google/protobuf/descriptor.proto\x1a\x17validate/validate.proto\"o\n\x17\x46ieldSecurityAnnotation\x12*\n\"configure_for_untrusted_downstream\x18\x01 \x01(\x08\x12(\n configure_for_untrusted_upstream\x18\x02 \x01(\x08:]\n\x08security\x12\x1d.google.protobuf.FieldOptions\x18\xb1\xf2\xa6\x05 \x01(\x0b\x32).udpa.annotations.FieldSecurityAnnotationB\x08\xba\x80\xc8\xd1\x06\x02\x08\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])


SECURITY_FIELD_NUMBER = 11122993
security = _descriptor.FieldDescriptor(
  name='security', full_name='udpa.annotations.security', index=0,
  number=11122993, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_FIELDSECURITYANNOTATION = _descriptor.Descriptor(
  name='FieldSecurityAnnotation',
  full_name='udpa.annotations.FieldSecurityAnnotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='configure_for_untrusted_downstream', full_name='udpa.annotations.FieldSecurityAnnotation.configure_for_untrusted_downstream', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configure_for_untrusted_upstream', full_name='udpa.annotations.FieldSecurityAnnotation.configure_for_untrusted_upstream', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=281,
)

DESCRIPTOR.message_types_by_name['FieldSecurityAnnotation'] = _FIELDSECURITYANNOTATION
DESCRIPTOR.extensions_by_name['security'] = security
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FieldSecurityAnnotation = _reflection.GeneratedProtocolMessageType('FieldSecurityAnnotation', (_message.Message,), {
  'DESCRIPTOR' : _FIELDSECURITYANNOTATION,
  '__module__' : 'udpa.annotations.security_pb2'
  # @@protoc_insertion_point(class_scope:udpa.annotations.FieldSecurityAnnotation)
  })
_sym_db.RegisterMessage(FieldSecurityAnnotation)

security.message_type = _FIELDSECURITYANNOTATION
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(security)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/adaptive_concurrency/v2alpha/adaptive_concurrency.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/adaptive_concurrency/v2alpha/adaptive_concurrency.proto',
  package='envoy.config.filter.http.adaptive_concurrency.v2alpha',
  syntax='proto3',
  serialized_options=b'\nCio.envoyproxy.envoy.config.filter.http.adaptive_concurrency.v2alphaB\030AdaptiveConcurrencyProtoP\001\362\230\376\217\0057\0225envoy.extensions.filters.http.adaptive_concurrency.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nPenvoy/config/filter/http/adaptive_concurrency/v2alpha/adaptive_concurrency.proto\x12\x35\x65nvoy.config.filter.http.adaptive_concurrency.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x18\x65nvoy/type/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe2\x06\n\x18GradientControllerConfig\x12\x38\n\x1bsample_aggregate_percentile\x18\x01 \x01(\x0b\x32\x13.envoy.type.Percent\x12\x9d\x01\n\x18\x63oncurrency_limit_params\x18\x02 \x01(\x0b\x32q.envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.ConcurrencyLimitCalculationParamsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x92\x01\n\x13min_rtt_calc_params\x18\x03 \x01(\x0b\x32k.envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.MinimumRTTCalculationParamsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1a\xb5\x01\n!ConcurrencyLimitCalculationParams\x12\x44\n\x15max_concurrency_limit\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12J\n\x1b\x63oncurrency_update_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x1a\x9e\x02\n\x1bMinimumRTTCalculationParams\x12\x37\n\x08interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x12<\n\rrequest_count\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12#\n\x06jitter\x18\x03 \x01(\x0b\x32\x13.envoy.type.Percent\x12>\n\x0fmin_concurrency\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12#\n\x06\x62uffer\x18\x05 \x01(\x0b\x32\x13.envoy.type.Percent\"\xf4\x01\n\x13\x41\x64\x61ptiveConcurrency\x12\x7f\n\x1agradient_controller_config\x18\x01 \x01(\x0b\x32O.envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00\x12\x36\n\x07\x65nabled\x18\x02 \x01(\x0b\x32%.envoy.api.v2.core.RuntimeFeatureFlagB$\n\x1d\x63oncurrency_controller_config\x12\x03\xf8\x42\x01\x42\xa6\x01\nCio.envoyproxy.envoy.config.filter.http.adaptive_concurrency.v2alphaB\x18\x41\x64\x61ptiveConcurrencyProtoP\x01\xf2\x98\xfe\x8f\x05\x37\x12\x35\x65nvoy.extensions.filters.http.adaptive_concurrency.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_type_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_GRADIENTCONTROLLERCONFIG_CONCURRENCYLIMITCALCULATIONPARAMS = _descriptor.Descriptor(
  name='ConcurrencyLimitCalculationParams',
  full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.ConcurrencyLimitCalculationParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_concurrency_limit', full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.ConcurrencyLimitCalculationParams.max_concurrency_limit', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='concurrency_update_interval', full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.ConcurrencyLimitCalculationParams.concurrency_update_interval', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\252\001\004\010\001*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=744,
  serialized_end=925,
)

_GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS = _descriptor.Descriptor(
  name='MinimumRTTCalculationParams',
  full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.MinimumRTTCalculationParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interval', full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.MinimumRTTCalculationParams.interval', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\252\001\004\010\001*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_count', full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.MinimumRTTCalculationParams.request_count', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jitter', full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.MinimumRTTCalculationParams.jitter', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_concurrency', full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.MinimumRTTCalculationParams.min_concurrency', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer', full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.MinimumRTTCalculationParams.buffer', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=928,
  serialized_end=1214,
)

_GRADIENTCONTROLLERCONFIG = _descriptor.Descriptor(
  name='GradientControllerConfig',
  full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sample_aggregate_percentile', full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.sample_aggregate_percentile', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='concurrency_limit_params', full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.concurrency_limit_params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_rtt_calc_params', full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.min_rtt_calc_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GRADIENTCONTROLLERCONFIG_CONCURRENCYLIMITCALCULATIONPARAMS, _GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=1214,
)


_ADAPTIVECONCURRENCY = _descriptor.Descriptor(
  name='AdaptiveConcurrency',
  full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.AdaptiveConcurrency',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gradient_controller_config', full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.AdaptiveConcurrency.gradient_controller_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.AdaptiveConcurrency.enabled', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='concurrency_controller_config', full_name='envoy.config.filter.http.adaptive_concurrency.v2alpha.AdaptiveConcurrency.concurrency_controller_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1217,
  serialized_end=1461,
)

_GRADIENTCONTROLLERCONFIG_CONCURRENCYLIMITCALCULATIONPARAMS.fields_by_name['max_concurrency_limit'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GRADIENTCONTROLLERCONFIG_CONCURRENCYLIMITCALCULATIONPARAMS.fields_by_name['concurrency_update_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_GRADIENTCONTROLLERCONFIG_CONCURRENCYLIMITCALCULATIONPARAMS.containing_type = _GRADIENTCONTROLLERCONFIG
_GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS.fields_by_name['request_count'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS.fields_by_name['jitter'].message_type = envoy_dot_type_dot_percent__pb2._PERCENT
_GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS.fields_by_name['min_concurrency'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS.fields_by_name['buffer'].message_type = envoy_dot_type_dot_percent__pb2._PERCENT
_GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS.containing_type = _GRADIENTCONTROLLERCONFIG
_GRADIENTCONTROLLERCONFIG.fields_by_name['sample_aggregate_percentile'].message_type = envoy_dot_type_dot_percent__pb2._PERCENT
_GRADIENTCONTROLLERCONFIG.fields_by_name['concurrency_limit_params'].message_type = _GRADIENTCONTROLLERCONFIG_CONCURRENCYLIMITCALCULATIONPARAMS
_GRADIENTCONTROLLERCONFIG.fields_by_name['min_rtt_calc_params'].message_type = _GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS
_ADAPTIVECONCURRENCY.fields_by_name['gradient_controller_config'].message_type = _GRADIENTCONTROLLERCONFIG
_ADAPTIVECONCURRENCY.fields_by_name['enabled'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._RUNTIMEFEATUREFLAG
_ADAPTIVECONCURRENCY.oneofs_by_name['concurrency_controller_config'].fields.append(
  _ADAPTIVECONCURRENCY.fields_by_name['gradient_controller_config'])
_ADAPTIVECONCURRENCY.fields_by_name['gradient_controller_config'].containing_oneof = _ADAPTIVECONCURRENCY.oneofs_by_name['concurrency_controller_config']
DESCRIPTOR.message_types_by_name['GradientControllerConfig'] = _GRADIENTCONTROLLERCONFIG
DESCRIPTOR.message_types_by_name['AdaptiveConcurrency'] = _ADAPTIVECONCURRENCY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GradientControllerConfig = _reflection.GeneratedProtocolMessageType('GradientControllerConfig', (_message.Message,), {

  'ConcurrencyLimitCalculationParams' : _reflection.GeneratedProtocolMessageType('ConcurrencyLimitCalculationParams', (_message.Message,), {
    'DESCRIPTOR' : _GRADIENTCONTROLLERCONFIG_CONCURRENCYLIMITCALCULATIONPARAMS,
    '__module__' : 'envoy.config.filter.http.adaptive_concurrency.v2alpha.adaptive_concurrency_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.ConcurrencyLimitCalculationParams)
    })
  ,

  'MinimumRTTCalculationParams' : _reflection.GeneratedProtocolMessageType('MinimumRTTCalculationParams', (_message.Message,), {
    'DESCRIPTOR' : _GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS,
    '__module__' : 'envoy.config.filter.http.adaptive_concurrency.v2alpha.adaptive_concurrency_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig.MinimumRTTCalculationParams)
    })
  ,
  'DESCRIPTOR' : _GRADIENTCONTROLLERCONFIG,
  '__module__' : 'envoy.config.filter.http.adaptive_concurrency.v2alpha.adaptive_concurrency_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.adaptive_concurrency.v2alpha.GradientControllerConfig)
  })
_sym_db.RegisterMessage(GradientControllerConfig)
_sym_db.RegisterMessage(GradientControllerConfig.ConcurrencyLimitCalculationParams)
_sym_db.RegisterMessage(GradientControllerConfig.MinimumRTTCalculationParams)

AdaptiveConcurrency = _reflection.GeneratedProtocolMessageType('AdaptiveConcurrency', (_message.Message,), {
  'DESCRIPTOR' : _ADAPTIVECONCURRENCY,
  '__module__' : 'envoy.config.filter.http.adaptive_concurrency.v2alpha.adaptive_concurrency_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.adaptive_concurrency.v2alpha.AdaptiveConcurrency)
  })
_sym_db.RegisterMessage(AdaptiveConcurrency)


DESCRIPTOR._options = None
_GRADIENTCONTROLLERCONFIG_CONCURRENCYLIMITCALCULATIONPARAMS.fields_by_name['max_concurrency_limit']._options = None
_GRADIENTCONTROLLERCONFIG_CONCURRENCYLIMITCALCULATIONPARAMS.fields_by_name['concurrency_update_interval']._options = None
_GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS.fields_by_name['interval']._options = None
_GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS.fields_by_name['request_count']._options = None
_GRADIENTCONTROLLERCONFIG_MINIMUMRTTCALCULATIONPARAMS.fields_by_name['min_concurrency']._options = None
_GRADIENTCONTROLLERCONFIG.fields_by_name['concurrency_limit_params']._options = None
_GRADIENTCONTROLLERCONFIG.fields_by_name['min_rtt_calc_params']._options = None
_ADAPTIVECONCURRENCY.oneofs_by_name['concurrency_controller_config']._options = None
_ADAPTIVECONCURRENCY.fields_by_name['gradient_controller_config']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1beta1/source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/expr/v1beta1/source.proto',
  package='google.api.expr.v1beta1',
  syntax='proto3',
  serialized_options=b'\n\033com.google.api.expr.v1beta1B\013SourceProtoP\001Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$google/api/expr/v1beta1/source.proto\x12\x17google.api.expr.v1beta1\"\xad\x01\n\nSourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x14\n\x0cline_offsets\x18\x03 \x03(\x05\x12\x45\n\tpositions\x18\x04 \x03(\x0b\x32\x32.google.api.expr.v1beta1.SourceInfo.PositionsEntry\x1a\x30\n\x0ePositionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"P\n\x0eSourcePosition\x12\x10\n\x08location\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x05\x12\x0c\n\x04line\x18\x03 \x01(\x05\x12\x0e\n\x06\x63olumn\x18\x04 \x01(\x05\x42l\n\x1b\x63om.google.api.expr.v1beta1B\x0bSourceProtoP\x01Z;google.golang.org/genproto/googleapis/api/expr/v1beta1;expr\xf8\x01\x01\x62\x06proto3'
)




_SOURCEINFO_POSITIONSENTRY = _descriptor.Descriptor(
  name='PositionsEntry',
  full_name='google.api.expr.v1beta1.SourceInfo.PositionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.api.expr.v1beta1.SourceInfo.PositionsEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1beta1.SourceInfo.PositionsEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=239,
)

_SOURCEINFO = _descriptor.Descriptor(
  name='SourceInfo',
  full_name='google.api.expr.v1beta1.SourceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='google.api.expr.v1beta1.SourceInfo.location', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line_offsets', full_name='google.api.expr.v1beta1.SourceInfo.line_offsets', index=1,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positions', full_name='google.api.expr.v1beta1.SourceInfo.positions', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SOURCEINFO_POSITIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=239,
)


_SOURCEPOSITION = _descriptor.Descriptor(
  name='SourcePosition',
  full_name='google.api.expr.v1beta1.SourcePosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='google.api.expr.v1beta1.SourcePosition.location', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='google.api.expr.v1beta1.SourcePosition.offset', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line', full_name='google.api.expr.v1beta1.SourcePosition.line', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column', full_name='google.api.expr.v1beta1.SourcePosition.column', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=321,
)

_SOURCEINFO_POSITIONSENTRY.containing_type = _SOURCEINFO
_SOURCEINFO.fields_by_name['positions'].message_type = _SOURCEINFO_POSITIONSENTRY
DESCRIPTOR.message_types_by_name['SourceInfo'] = _SOURCEINFO
DESCRIPTOR.message_types_by_name['SourcePosition'] = _SOURCEPOSITION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SourceInfo = _reflection.GeneratedProtocolMessageType('SourceInfo', (_message.Message,), {

  'PositionsEntry' : _reflection.GeneratedProtocolMessageType('PositionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SOURCEINFO_POSITIONSENTRY,
    '__module__' : 'google.api.expr.v1beta1.source_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.SourceInfo.PositionsEntry)
    })
  ,
  'DESCRIPTOR' : _SOURCEINFO,
  '__module__' : 'google.api.expr.v1beta1.source_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.SourceInfo)
  })
_sym_db.RegisterMessage(SourceInfo)
_sym_db.RegisterMessage(SourceInfo.PositionsEntry)

SourcePosition = _reflection.GeneratedProtocolMessageType('SourcePosition', (_message.Message,), {
  'DESCRIPTOR' : _SOURCEPOSITION,
  '__module__' : 'google.api.expr.v1beta1.source_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1beta1.SourcePosition)
  })
_sym_db.RegisterMessage(SourcePosition)


DESCRIPTOR._options = None
_SOURCEINFO_POSITIONSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/expr/v1alpha1/conformance_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api.expr.v1alpha1 import checked_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_checked__pb2
from google.api.expr.v1alpha1 import eval_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_eval__pb2
from google.api.expr.v1alpha1 import syntax_pb2 as google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/expr/v1alpha1/conformance_service.proto',
  package='google.api.expr.v1alpha1',
  syntax='proto3',
  serialized_options=b'\n\034com.google.api.expr.v1alpha1B\027ConformanceServiceProtoP\001Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2google/api/expr/v1alpha1/conformance_service.proto\x12\x18google.api.expr.v1alpha1\x1a\x17google/api/client.proto\x1a&google/api/expr/v1alpha1/checked.proto\x1a#google/api/expr/v1alpha1/eval.proto\x1a%google/api/expr/v1alpha1/syntax.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x17google/rpc/status.proto\"p\n\x0cParseRequest\x12\x17\n\ncel_source\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\x0esyntax_version\x18\x02 \x01(\t\x12\x17\n\x0fsource_location\x18\x03 \x01(\t\x12\x16\n\x0e\x64isable_macros\x18\x04 \x01(\x08\"n\n\rParseResponse\x12\x39\n\x0bparsed_expr\x18\x01 \x01(\x0b\x32$.google.api.expr.v1alpha1.ParsedExpr\x12\"\n\x06issues\x18\x02 \x03(\x0b\x32\x12.google.rpc.Status\"\xa7\x01\n\x0c\x43heckRequest\x12>\n\x0bparsed_expr\x18\x01 \x01(\x0b\x32$.google.api.expr.v1alpha1.ParsedExprB\x03\xe0\x41\x02\x12\x30\n\x08type_env\x18\x02 \x03(\x0b\x32\x1e.google.api.expr.v1alpha1.Decl\x12\x11\n\tcontainer\x18\x03 \x01(\t\x12\x12\n\nno_std_env\x18\x04 \x01(\x08\"p\n\rCheckResponse\x12;\n\x0c\x63hecked_expr\x18\x01 \x01(\x0b\x32%.google.api.expr.v1alpha1.CheckedExpr\x12\"\n\x06issues\x18\x02 \x03(\x0b\x32\x12.google.rpc.Status\"\xc6\x02\n\x0b\x45valRequest\x12;\n\x0bparsed_expr\x18\x01 \x01(\x0b\x32$.google.api.expr.v1alpha1.ParsedExprH\x00\x12=\n\x0c\x63hecked_expr\x18\x02 \x01(\x0b\x32%.google.api.expr.v1alpha1.CheckedExprH\x00\x12\x45\n\x08\x62indings\x18\x03 \x03(\x0b\x32\x33.google.api.expr.v1alpha1.EvalRequest.BindingsEntry\x12\x11\n\tcontainer\x18\x04 \x01(\t\x1aT\n\rBindingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.google.api.expr.v1alpha1.ExprValue:\x02\x38\x01\x42\x0b\n\texpr_kind\"g\n\x0c\x45valResponse\x12\x33\n\x06result\x18\x01 \x01(\x0b\x32#.google.api.expr.v1alpha1.ExprValue\x12\"\n\x06issues\x18\x02 \x03(\x0b\x32\x12.google.rpc.Status\"\xe8\x01\n\x0cIssueDetails\x12\x41\n\x08severity\x18\x01 \x01(\x0e\x32/.google.api.expr.v1alpha1.IssueDetails.Severity\x12:\n\x08position\x18\x02 \x01(\x0b\x32(.google.api.expr.v1alpha1.SourcePosition\x12\n\n\x02id\x18\x03 \x01(\x03\"M\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x44\x45PRECATION\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x32\xd7\x02\n\x12\x43onformanceService\x12g\n\x05Parse\x12&.google.api.expr.v1alpha1.ParseRequest\x1a\'.google.api.expr.v1alpha1.ParseResponse\"\r\xda\x41\ncel_source\x12h\n\x05\x43heck\x12&.google.api.expr.v1alpha1.CheckRequest\x1a\'.google.api.expr.v1alpha1.CheckResponse\"\x0e\xda\x41\x0bparsed_expr\x12W\n\x04\x45val\x12%.google.api.expr.v1alpha1.EvalRequest\x1a&.google.api.expr.v1alpha1.EvalResponse\"\x00\x1a\x15\xca\x41\x12\x63\x65l.googleapis.comBz\n\x1c\x63om.google.api.expr.v1alpha1B\x17\x43onformanceServiceProtoP\x01Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_client__pb2.DESCRIPTOR,google_dot_api_dot_expr_dot_v1alpha1_dot_checked__pb2.DESCRIPTOR,google_dot_api_dot_expr_dot_v1alpha1_dot_eval__pb2.DESCRIPTOR,google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])



_ISSUEDETAILS_SEVERITY = _descriptor.EnumDescriptor(
  name='Severity',
  full_name='google.api.expr.v1alpha1.IssueDetails.Severity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEPRECATION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1379,
  serialized_end=1456,
)
_sym_db.RegisterEnumDescriptor(_ISSUEDETAILS_SEVERITY)


_PARSEREQUEST = _descriptor.Descriptor(
  name='ParseRequest',
  full_name='google.api.expr.v1alpha1.ParseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cel_source', full_name='google.api.expr.v1alpha1.ParseRequest.cel_source', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='syntax_version', full_name='google.api.expr.v1alpha1.ParseRequest.syntax_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_location', full_name='google.api.expr.v1alpha1.ParseRequest.source_location', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_macros', full_name='google.api.expr.v1alpha1.ParseRequest.disable_macros', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=391,
)


_PARSERESPONSE = _descriptor.Descriptor(
  name='ParseResponse',
  full_name='google.api.expr.v1alpha1.ParseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parsed_expr', full_name='google.api.expr.v1alpha1.ParseResponse.parsed_expr', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='google.api.expr.v1alpha1.ParseResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=503,
)


_CHECKREQUEST = _descriptor.Descriptor(
  name='CheckRequest',
  full_name='google.api.expr.v1alpha1.CheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parsed_expr', full_name='google.api.expr.v1alpha1.CheckRequest.parsed_expr', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_env', full_name='google.api.expr.v1alpha1.CheckRequest.type_env', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='container', full_name='google.api.expr.v1alpha1.CheckRequest.container', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_std_env', full_name='google.api.expr.v1alpha1.CheckRequest.no_std_env', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=506,
  serialized_end=673,
)


_CHECKRESPONSE = _descriptor.Descriptor(
  name='CheckResponse',
  full_name='google.api.expr.v1alpha1.CheckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='checked_expr', full_name='google.api.expr.v1alpha1.CheckResponse.checked_expr', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='google.api.expr.v1alpha1.CheckResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=675,
  serialized_end=787,
)


_EVALREQUEST_BINDINGSENTRY = _descriptor.Descriptor(
  name='BindingsEntry',
  full_name='google.api.expr.v1alpha1.EvalRequest.BindingsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.api.expr.v1alpha1.EvalRequest.BindingsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.expr.v1alpha1.EvalRequest.BindingsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1019,
  serialized_end=1103,
)

_EVALREQUEST = _descriptor.Descriptor(
  name='EvalRequest',
  full_name='google.api.expr.v1alpha1.EvalRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parsed_expr', full_name='google.api.expr.v1alpha1.EvalRequest.parsed_expr', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checked_expr', full_name='google.api.expr.v1alpha1.EvalRequest.checked_expr', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bindings', full_name='google.api.expr.v1alpha1.EvalRequest.bindings', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='container', full_name='google.api.expr.v1alpha1.EvalRequest.container', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EVALREQUEST_BINDINGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='expr_kind', full_name='google.api.expr.v1alpha1.EvalRequest.expr_kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=790,
  serialized_end=1116,
)


_EVALRESPONSE = _descriptor.Descriptor(
  name='EvalResponse',
  full_name='google.api.expr.v1alpha1.EvalResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='google.api.expr.v1alpha1.EvalResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='google.api.expr.v1alpha1.EvalResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1118,
  serialized_end=1221,
)


_ISSUEDETAILS = _descriptor.Descriptor(
  name='IssueDetails',
  full_name='google.api.expr.v1alpha1.IssueDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='severity', full_name='google.api.expr.v1alpha1.IssueDetails.severity', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position', full_name='google.api.expr.v1alpha1.IssueDetails.position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.api.expr.v1alpha1.IssueDetails.id', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ISSUEDETAILS_SEVERITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1224,
  serialized_end=1456,
)

_PARSERESPONSE.fields_by_name['parsed_expr'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2._PARSEDEXPR
_PARSERESPONSE.fields_by_name['issues'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_CHECKREQUEST.fields_by_name['parsed_expr'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2._PARSEDEXPR
_CHECKREQUEST.fields_by_name['type_env'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_checked__pb2._DECL
_CHECKRESPONSE.fields_by_name['checked_expr'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_checked__pb2._CHECKEDEXPR
_CHECKRESPONSE.fields_by_name['issues'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_EVALREQUEST_BINDINGSENTRY.fields_by_name['value'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_eval__pb2._EXPRVALUE
_EVALREQUEST_BINDINGSENTRY.containing_type = _EVALREQUEST
_EVALREQUEST.fields_by_name['parsed_expr'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2._PARSEDEXPR
_EVALREQUEST.fields_by_name['checked_expr'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_checked__pb2._CHECKEDEXPR
_EVALREQUEST.fields_by_name['bindings'].message_type = _EVALREQUEST_BINDINGSENTRY
_EVALREQUEST.oneofs_by_name['expr_kind'].fields.append(
  _EVALREQUEST.fields_by_name['parsed_expr'])
_EVALREQUEST.fields_by_name['parsed_expr'].containing_oneof = _EVALREQUEST.oneofs_by_name['expr_kind']
_EVALREQUEST.oneofs_by_name['expr_kind'].fields.append(
  _EVALREQUEST.fields_by_name['checked_expr'])
_EVALREQUEST.fields_by_name['checked_expr'].containing_oneof = _EVALREQUEST.oneofs_by_name['expr_kind']
_EVALRESPONSE.fields_by_name['result'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_eval__pb2._EXPRVALUE
_EVALRESPONSE.fields_by_name['issues'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_ISSUEDETAILS.fields_by_name['severity'].enum_type = _ISSUEDETAILS_SEVERITY
_ISSUEDETAILS.fields_by_name['position'].message_type = google_dot_api_dot_expr_dot_v1alpha1_dot_syntax__pb2._SOURCEPOSITION
_ISSUEDETAILS_SEVERITY.containing_type = _ISSUEDETAILS
DESCRIPTOR.message_types_by_name['ParseRequest'] = _PARSEREQUEST
DESCRIPTOR.message_types_by_name['ParseResponse'] = _PARSERESPONSE
DESCRIPTOR.message_types_by_name['CheckRequest'] = _CHECKREQUEST
DESCRIPTOR.message_types_by_name['CheckResponse'] = _CHECKRESPONSE
DESCRIPTOR.message_types_by_name['EvalRequest'] = _EVALREQUEST
DESCRIPTOR.message_types_by_name['EvalResponse'] = _EVALRESPONSE
DESCRIPTOR.message_types_by_name['IssueDetails'] = _ISSUEDETAILS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ParseRequest = _reflection.GeneratedProtocolMessageType('ParseRequest', (_message.Message,), {
  'DESCRIPTOR' : _PARSEREQUEST,
  '__module__' : 'google.api.expr.v1alpha1.conformance_service_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.ParseRequest)
  })
_sym_db.RegisterMessage(ParseRequest)

ParseResponse = _reflection.GeneratedProtocolMessageType('ParseResponse', (_message.Message,), {
  'DESCRIPTOR' : _PARSERESPONSE,
  '__module__' : 'google.api.expr.v1alpha1.conformance_service_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.ParseResponse)
  })
_sym_db.RegisterMessage(ParseResponse)

CheckRequest = _reflection.GeneratedProtocolMessageType('CheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKREQUEST,
  '__module__' : 'google.api.expr.v1alpha1.conformance_service_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.CheckRequest)
  })
_sym_db.RegisterMessage(CheckRequest)

CheckResponse = _reflection.GeneratedProtocolMessageType('CheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHECKRESPONSE,
  '__module__' : 'google.api.expr.v1alpha1.conformance_service_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.CheckResponse)
  })
_sym_db.RegisterMessage(CheckResponse)

EvalRequest = _reflection.GeneratedProtocolMessageType('EvalRequest', (_message.Message,), {

  'BindingsEntry' : _reflection.GeneratedProtocolMessageType('BindingsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EVALREQUEST_BINDINGSENTRY,
    '__module__' : 'google.api.expr.v1alpha1.conformance_service_pb2'
    # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.EvalRequest.BindingsEntry)
    })
  ,
  'DESCRIPTOR' : _EVALREQUEST,
  '__module__' : 'google.api.expr.v1alpha1.conformance_service_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.EvalRequest)
  })
_sym_db.RegisterMessage(EvalRequest)
_sym_db.RegisterMessage(EvalRequest.BindingsEntry)

EvalResponse = _reflection.GeneratedProtocolMessageType('EvalResponse', (_message.Message,), {
  'DESCRIPTOR' : _EVALRESPONSE,
  '__module__' : 'google.api.expr.v1alpha1.conformance_service_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.EvalResponse)
  })
_sym_db.RegisterMessage(EvalResponse)

IssueDetails = _reflection.GeneratedProtocolMessageType('IssueDetails', (_message.Message,), {
  'DESCRIPTOR' : _ISSUEDETAILS,
  '__module__' : 'google.api.expr.v1alpha1.conformance_service_pb2'
  # @@protoc_insertion_point(class_scope:google.api.expr.v1alpha1.IssueDetails)
  })
_sym_db.RegisterMessage(IssueDetails)


DESCRIPTOR._options = None
_PARSEREQUEST.fields_by_name['cel_source']._options = None
_CHECKREQUEST.fields_by_name['parsed_expr']._options = None
_EVALREQUEST_BINDINGSENTRY._options = None

_CONFORMANCESERVICE = _descriptor.ServiceDescriptor(
  name='ConformanceService',
  full_name='google.api.expr.v1alpha1.ConformanceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\312A\022cel.googleapis.com',
  create_key=_descriptor._internal_create_key,
  serialized_start=1459,
  serialized_end=1802,
  methods=[
  _descriptor.MethodDescriptor(
    name='Parse',
    full_name='google.api.expr.v1alpha1.ConformanceService.Parse',
    index=0,
    containing_service=None,
    input_type=_PARSEREQUEST,
    output_type=_PARSERESPONSE,
    serialized_options=b'\332A\ncel_source',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Check',
    full_name='google.api.expr.v1alpha1.ConformanceService.Check',
    index=1,
    containing_service=None,
    input_type=_CHECKREQUEST,
    output_type=_CHECKRESPONSE,
    serialized_options=b'\332A\013parsed_expr',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Eval',
    full_name='google.api.expr.v1alpha1.ConformanceService.Eval',
    index=2,
    containing_service=None,
    input_type=_EVALREQUEST,
    output_type=_EVALRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONFORMANCESERVICE)

DESCRIPTOR.services_by_name['ConformanceService'] = _CONFORMANCESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: udpa/annotations/versioning.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='udpa/annotations/versioning.proto',
  package='udpa.annotations',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!udpa/annotations/versioning.proto\x12\x10udpa.annotations\x1a google/protobuf/descriptor.proto\"5\n\x14VersioningAnnotation\x12\x1d\n\x15previous_message_type\x18\x01 \x01(\t:^\n\nversioning\x12\x1f.google.protobuf.MessageOptions\x18\xd3\x88\xe1\x03 \x01(\x0b\x32&.udpa.annotations.VersioningAnnotationb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


VERSIONING_FIELD_NUMBER = 7881811
versioning = _descriptor.FieldDescriptor(
  name='versioning', full_name='udpa.annotations.versioning', index=0,
  number=7881811, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_VERSIONINGANNOTATION = _descriptor.Descriptor(
  name='VersioningAnnotation',
  full_name='udpa.annotations.VersioningAnnotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='previous_message_type', full_name='udpa.annotations.VersioningAnnotation.previous_message_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=142,
)

DESCRIPTOR.message_types_by_name['VersioningAnnotation'] = _VERSIONINGANNOTATION
DESCRIPTOR.extensions_by_name['versioning'] = versioning
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VersioningAnnotation = _reflection.GeneratedProtocolMessageType('VersioningAnnotation', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONINGANNOTATION,
  '__module__' : 'udpa.annotations.versioning_pb2'
  # @@protoc_insertion_point(class_scope:udpa.annotations.VersioningAnnotation)
  })
_sym_db.RegisterMessage(VersioningAnnotation)

versioning.message_type = _VERSIONINGANNOTATION
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(versioning)

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/tracers/skywalking/v4alpha/skywalking.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/tracers/skywalking/v4alpha/skywalking.proto',
  package='envoy.extensions.tracers.skywalking.v4alpha',
  syntax='proto3',
  serialized_options=b'\n9io.envoyproxy.envoy.extensions.tracers.skywalking.v4alphaB\017SkywalkingProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n<envoy/extensions/tracers/skywalking/v4alpha/skywalking.proto\x12+envoy.extensions.tracers.skywalking.v4alpha\x1a,envoy/config/core/v4alpha/grpc_service.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xdb\x01\n\x10SkyWalkingConfig\x12\x46\n\x0cgrpc_service\x18\x01 \x01(\x0b\x32&.envoy.config.core.v4alpha.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12P\n\rclient_config\x18\x02 \x01(\x0b\x32\x39.envoy.extensions.tracers.skywalking.v4alpha.ClientConfig:-\x9a\xc5\x88\x1e(\n&envoy.config.trace.v3.SkyWalkingConfig\"\xd8\x01\n\x0c\x43lientConfig\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x15\n\rinstance_name\x18\x02 \x01(\t\x12\x1f\n\rbackend_token\x18\x03 \x01(\tB\x06\xb8\xb7\x8b\xa4\x02\x01H\x00\x12\x34\n\x0emax_cache_size\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value:)\x9a\xc5\x88\x1e$\n\"envoy.config.trace.v3.ClientConfigB\x19\n\x17\x62\x61\x63kend_token_specifierBV\n9io.envoyproxy.envoy.extensions.tracers.skywalking.v4alphaB\x0fSkywalkingProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_sensitive__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_SKYWALKINGCONFIG = _descriptor.Descriptor(
  name='SkyWalkingConfig',
  full_name='envoy.extensions.tracers.skywalking.v4alpha.SkyWalkingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grpc_service', full_name='envoy.extensions.tracers.skywalking.v4alpha.SkyWalkingConfig.grpc_service', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_config', full_name='envoy.extensions.tracers.skywalking.v4alpha.SkyWalkingConfig.client_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.config.trace.v3.SkyWalkingConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=532,
)


_CLIENTCONFIG = _descriptor.Descriptor(
  name='ClientConfig',
  full_name='envoy.extensions.tracers.skywalking.v4alpha.ClientConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='envoy.extensions.tracers.skywalking.v4alpha.ClientConfig.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_name', full_name='envoy.extensions.tracers.skywalking.v4alpha.ClientConfig.instance_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backend_token', full_name='envoy.extensions.tracers.skywalking.v4alpha.ClientConfig.backend_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\270\267\213\244\002\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_cache_size', full_name='envoy.extensions.tracers.skywalking.v4alpha.ClientConfig.max_cache_size', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.config.trace.v3.ClientConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='backend_token_specifier', full_name='envoy.extensions.tracers.skywalking.v4alpha.ClientConfig.backend_token_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=535,
  serialized_end=751,
)

_SKYWALKINGCONFIG.fields_by_name['grpc_service'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_grpc__service__pb2._GRPCSERVICE
_SKYWALKINGCONFIG.fields_by_name['client_config'].message_type = _CLIENTCONFIG
_CLIENTCONFIG.fields_by_name['max_cache_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CLIENTCONFIG.oneofs_by_name['backend_token_specifier'].fields.append(
  _CLIENTCONFIG.fields_by_name['backend_token'])
_CLIENTCONFIG.fields_by_name['backend_token'].containing_oneof = _CLIENTCONFIG.oneofs_by_name['backend_token_specifier']
DESCRIPTOR.message_types_by_name['SkyWalkingConfig'] = _SKYWALKINGCONFIG
DESCRIPTOR.message_types_by_name['ClientConfig'] = _CLIENTCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SkyWalkingConfig = _reflection.GeneratedProtocolMessageType('SkyWalkingConfig', (_message.Message,), {
  'DESCRIPTOR' : _SKYWALKINGCONFIG,
  '__module__' : 'envoy.extensions.tracers.skywalking.v4alpha.skywalking_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.tracers.skywalking.v4alpha.SkyWalkingConfig)
  })
_sym_db.RegisterMessage(SkyWalkingConfig)

ClientConfig = _reflection.GeneratedProtocolMessageType('ClientConfig', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTCONFIG,
  '__module__' : 'envoy.extensions.tracers.skywalking.v4alpha.skywalking_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.tracers.skywalking.v4alpha.ClientConfig)
  })
_sym_db.RegisterMessage(ClientConfig)


DESCRIPTOR._options = None
_SKYWALKINGCONFIG.fields_by_name['grpc_service']._options = None
_SKYWALKINGCONFIG._options = None
_CLIENTCONFIG.fields_by_name['backend_token']._options = None
_CLIENTCONFIG._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/retry/previous_priorities/previous_priorities_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/retry/previous_priorities/previous_priorities_config.proto',
  package='envoy.config.retry.previous_priorities',
  syntax='proto3',
  serialized_options=b'\n4io.envoyproxy.envoy.config.retry.previous_prioritiesB\035PreviousPrioritiesConfigProtoP\001\362\230\376\217\0058\0226envoy.extensions.retry.priority.previous_priorities.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nGenvoy/config/retry/previous_priorities/previous_priorities_config.proto\x12&envoy.config.retry.previous_priorities\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"=\n\x18PreviousPrioritiesConfig\x12!\n\x10update_frequency\x18\x01 \x01(\x05\x42\x07\xfa\x42\x04\x1a\x02 \x00\x42\x9d\x01\n4io.envoyproxy.envoy.config.retry.previous_prioritiesB\x1dPreviousPrioritiesConfigProtoP\x01\xf2\x98\xfe\x8f\x05\x38\x12\x36\x65nvoy.extensions.retry.priority.previous_priorities.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_PREVIOUSPRIORITIESCONFIG = _descriptor.Descriptor(
  name='PreviousPrioritiesConfig',
  full_name='envoy.config.retry.previous_priorities.PreviousPrioritiesConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_frequency', full_name='envoy.config.retry.previous_priorities.PreviousPrioritiesConfig.update_frequency', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004\032\002 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=264,
)

DESCRIPTOR.message_types_by_name['PreviousPrioritiesConfig'] = _PREVIOUSPRIORITIESCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PreviousPrioritiesConfig = _reflection.GeneratedProtocolMessageType('PreviousPrioritiesConfig', (_message.Message,), {
  'DESCRIPTOR' : _PREVIOUSPRIORITIESCONFIG,
  '__module__' : 'envoy.config.retry.previous_priorities.previous_priorities_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.retry.previous_priorities.PreviousPrioritiesConfig)
  })
_sym_db.RegisterMessage(PreviousPrioritiesConfig)


DESCRIPTOR._options = None
_PREVIOUSPRIORITIESCONFIG.fields_by_name['update_frequency']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/cdn_loop/v3alpha/cdn_loop.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/cdn_loop/v3alpha/cdn_loop.proto',
  package='envoy.extensions.filters.http.cdn_loop.v3alpha',
  syntax='proto3',
  serialized_options=b'\n<io.envoyproxy.envoy.extensions.filters.http.cdn_loop.v3alphaB\014CdnLoopProtoP\001\272\200\310\321\006\002\010\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=envoy/extensions/filters/http/cdn_loop/v3alpha/cdn_loop.proto\x12.envoy.extensions.filters.http.cdn_loop.v3alpha\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"I\n\rCdnLoopConfig\x12\x17\n\x06\x63\x64n_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1f\n\x17max_allowed_occurrences\x18\x02 \x01(\rB^\n<io.envoyproxy.envoy.extensions.filters.http.cdn_loop.v3alphaB\x0c\x43\x64nLoopProtoP\x01\xba\x80\xc8\xd1\x06\x02\x08\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CDNLOOPCONFIG = _descriptor.Descriptor(
  name='CdnLoopConfig',
  full_name='envoy.extensions.filters.http.cdn_loop.v3alpha.CdnLoopConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cdn_id', full_name='envoy.extensions.filters.http.cdn_loop.v3alpha.CdnLoopConfig.cdn_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_allowed_occurrences', full_name='envoy.extensions.filters.http.cdn_loop.v3alpha.CdnLoopConfig.max_allowed_occurrences', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=242,
)

DESCRIPTOR.message_types_by_name['CdnLoopConfig'] = _CDNLOOPCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CdnLoopConfig = _reflection.GeneratedProtocolMessageType('CdnLoopConfig', (_message.Message,), {
  'DESCRIPTOR' : _CDNLOOPCONFIG,
  '__module__' : 'envoy.extensions.filters.http.cdn_loop.v3alpha.cdn_loop_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.cdn_loop.v3alpha.CdnLoopConfig)
  })
_sym_db.RegisterMessage(CdnLoopConfig)


DESCRIPTOR._options = None
_CDNLOOPCONFIG.fields_by_name['cdn_id']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/servicecontrol/v1/operation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api.servicecontrol.v1 import log_entry_pb2 as google_dot_api_dot_servicecontrol_dot_v1_dot_log__entry__pb2
from google.api.servicecontrol.v1 import metric_value_pb2 as google_dot_api_dot_servicecontrol_dot_v1_dot_metric__value__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/servicecontrol/v1/operation.proto',
  package='google.api.servicecontrol.v1',
  syntax='proto3',
  serialized_options=b'\n com.google.api.servicecontrol.v1B\016OperationProtoP\001ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,google/api/servicecontrol/v1/operation.proto\x12\x1cgoogle.api.servicecontrol.v1\x1a\x1cgoogle/api/annotations.proto\x1a,google/api/servicecontrol/v1/log_entry.proto\x1a/google/api/servicecontrol/v1/metric_value.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8f\x04\n\tOperation\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12\x16\n\x0eoperation_name\x18\x02 \x01(\t\x12\x13\n\x0b\x63onsumer_id\x18\x03 \x01(\t\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x06labels\x18\x06 \x03(\x0b\x32\x33.google.api.servicecontrol.v1.Operation.LabelsEntry\x12G\n\x11metric_value_sets\x18\x07 \x03(\x0b\x32,.google.api.servicecontrol.v1.MetricValueSet\x12;\n\x0blog_entries\x18\x08 \x03(\x0b\x32&.google.api.servicecontrol.v1.LogEntry\x12\x46\n\nimportance\x18\x0b \x01(\x0e\x32\x32.google.api.servicecontrol.v1.Operation.Importance\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1f\n\nImportance\x12\x07\n\x03LOW\x10\x00\x12\x08\n\x04HIGH\x10\x01\x42\x83\x01\n com.google.api.servicecontrol.v1B\x0eOperationProtoP\x01ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_servicecontrol_dot_v1_dot_log__entry__pb2.DESCRIPTOR,google_dot_api_dot_servicecontrol_dot_v1_dot_metric__value__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_OPERATION_IMPORTANCE = _descriptor.EnumDescriptor(
  name='Importance',
  full_name='google.api.servicecontrol.v1.Operation.Importance',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOW', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGH', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=733,
  serialized_end=764,
)
_sym_db.RegisterEnumDescriptor(_OPERATION_IMPORTANCE)


_OPERATION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='google.api.servicecontrol.v1.Operation.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.api.servicecontrol.v1.Operation.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.servicecontrol.v1.Operation.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=686,
  serialized_end=731,
)

_OPERATION = _descriptor.Descriptor(
  name='Operation',
  full_name='google.api.servicecontrol.v1.Operation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_id', full_name='google.api.servicecontrol.v1.Operation.operation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_name', full_name='google.api.servicecontrol.v1.Operation.operation_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumer_id', full_name='google.api.servicecontrol.v1.Operation.consumer_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='google.api.servicecontrol.v1.Operation.start_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='google.api.servicecontrol.v1.Operation.end_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='google.api.servicecontrol.v1.Operation.labels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metric_value_sets', full_name='google.api.servicecontrol.v1.Operation.metric_value_sets', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_entries', full_name='google.api.servicecontrol.v1.Operation.log_entries', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='importance', full_name='google.api.servicecontrol.v1.Operation.importance', index=8,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OPERATION_LABELSENTRY, ],
  enum_types=[
    _OPERATION_IMPORTANCE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=764,
)

_OPERATION_LABELSENTRY.containing_type = _OPERATION
_OPERATION.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OPERATION.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OPERATION.fields_by_name['labels'].message_type = _OPERATION_LABELSENTRY
_OPERATION.fields_by_name['metric_value_sets'].message_type = google_dot_api_dot_servicecontrol_dot_v1_dot_metric__value__pb2._METRICVALUESET
_OPERATION.fields_by_name['log_entries'].message_type = google_dot_api_dot_servicecontrol_dot_v1_dot_log__entry__pb2._LOGENTRY
_OPERATION.fields_by_name['importance'].enum_type = _OPERATION_IMPORTANCE
_OPERATION_IMPORTANCE.containing_type = _OPERATION
DESCRIPTOR.message_types_by_name['Operation'] = _OPERATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Operation = _reflection.GeneratedProtocolMessageType('Operation', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _OPERATION_LABELSENTRY,
    '__module__' : 'google.api.servicecontrol.v1.operation_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.Operation.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _OPERATION,
  '__module__' : 'google.api.servicecontrol.v1.operation_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.Operation)
  })
_sym_db.RegisterMessage(Operation)
_sym_db.RegisterMessage(Operation.LabelsEntry)


DESCRIPTOR._options = None
_OPERATION_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)
